Welcome to py3dtiles's documentation!
=====================================

Py3dtiles is a Python tool and library for manipulating `3D Tiles`_.

.. _3D Tiles: https://github.com/AnalyticalGraphicsInc/3d-tiles

**CLI Features**

* Convert pointcloud LAS and XYZ files to a 3D Tiles tileset (tileset.json + pnts files)
* Merge pointcloud 3D Tiles tilesets into one tileset
* Read pnts and b3dm files and print a summary of their contents

**API features**

* Read/write pointcloud (pnts) and batched 3d model format

py3dtiles is distributed under the Apache 2 Licence.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install
   cli
   api
   API doc <api/py3dtiles>
   FAQ and Troubleshooting <faq>
   Changelog <changelog>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
